@@ -1,6 +1,7 @@
 .onAttach <- function(libname, pkgname) {
   packageStartupMessage(
     paste("This is ShinyItemAnalysis version "), packageVersion("ShinyItemAnalysis"),
-    "\nTo run interactive ShinyItemAnalysis application, print: startShinyItemAnalysis()"
+    "\nTo run interactive shiny app, print startShinyItemAnalysis()",
+    "\nTo learn more, visit www.ShinyItemAnalysis.org"
   )
 }
