@@ -87,7 +87,7 @@ uiReports <-
                                                              column(3,
                                                                     sliderInput(inputId = 'DDplotNumGroupsSlider_report',
                                                                                 label = 'Number of groups:',
-                                                                                min = 1,
+                                                                                min = 2,
                                                                                 max = 5,
                                                                                 value = 3)),
                                                              column(3,
@@ -133,14 +133,17 @@ uiReports <-
            ),
            tags$hr(),
            fluidRow(
-             column(3,
+             column(2,
                     p(strong("DIF method selection")),
                     checkboxInput(inputId = "histCheck",
-                                  label = "None - histograms by group only",
+                                  label = "None - histograms by group",
                                   value = FALSE),
                     checkboxInput(inputId = "deltaplotCheck",
                                   label = "Delta plot",
                                   value = FALSE),
+                    checkboxInput(inputId = "MHCheck",
+                                  label = "Mantel-Haenszel test",
+                                  value = FALSE),
                     checkboxInput(inputId = "logregCheck",
                                   label = "Logistic regression",
                                   value = FALSE),
@@ -169,25 +172,59 @@ uiReports <-
                                                       )
                                                )
                               ),
-                              conditionalPanel(condition = "input.logregCheck",
-                                               column(3, p(strong("Logistic regression settings")),
-                                                      withMathJax(),
-                                                      radioButtons(inputId = 'type_print_DIF_logistic_report',
-                                                                   label = 'Type',
-                                                                   choices = c("\\(H_{0}\\): Any DIF vs. \\(H_{1}\\): No DIF" = 'both',
-                                                                               "\\(H_{0}\\): Uniform DIF vs. \\(H_{1}\\): No DIF" = 'udif',
-                                                                               "\\(H_{0}\\): Non-Uniform DIF vs. \\(H_{1}\\): Uniform DIF" = 'nudif'),
-                                                                   selected = 'both'),
-                                                      selectInput(inputId = "correction_method_log_report",
+                              conditionalPanel(condition = "input.MHCheck",
+                                               column(2,
+                                                      p(strong("Mantel-Haenszel test settings")),
+                                                      # selectInput(inputId = "matching_MH_report",
+                                                      #             label = "DIF matching variable",
+                                                      #             choices = c("Total score" = "total_score",
+                                                      #                         "Standardized total score" = "zscore"
+                                                      #             ),
+                                                      #             selected = "score",
+                                                      #             width = "85%"),
+                                                      selectInput(inputId = "correction_method_MH_report",
                                                                   label = "Correction method",
                                                                   choices = c("Benjamini-Hochberg" = "BH",
                                                                               "Benjamini-Yekutieli" = "BY",
+                                                                              "Bonferroni" = "bonferroni",
                                                                               "Holm" = "holm",
                                                                               "Hochberg" = "hochberg",
                                                                               "Hommel" = "hommel",
                                                                               "None" = "none"),
                                                                   selected = "none",
-                                                                  width = "80%"),
+                                                                  width = "85%"),
+                                                      checkboxInput(inputId = 'puri_MH_report',
+                                                                    label = 'Item purification',
+                                                                    value = FALSE)
+                                               )
+                              ),
+                              conditionalPanel(condition = "input.logregCheck",
+                                               column(3, p(strong("Logistic regression settings")),
+                                                      withMathJax(),
+                                                      radioButtons(inputId = 'type_print_DIF_logistic_report',
+                                                                   label = 'Type',
+                                                                   choices = c("\\(H_{0}\\): No DIF vs. \\(H_{1}\\): Any DIF" = 'both',
+                                                                               "\\(H_{0}\\): No DIF vs. \\(H_{1}\\): Uniform DIF" = 'udif',
+                                                                               "\\(H_{0}\\): Uniform DIF vs. \\(H_{1}\\): Non-uniform DIF" = 'nudif'),
+                                                                   selected = 'both'),
+                                                      # selectInput(inputId = "matching_logistic_report",
+                                                      #             label = "DIF matching variable",
+                                                      #             choices = c("Total score" = "total_score",
+                                                      #                         "Standardized total score" = "zscore"
+                                                      #             ),
+                                                      #             selected = "score",
+                                                      #             width = "85%"),
+                                                      selectInput(inputId = "correction_method_log_report",
+                                                                  label = "Correction method",
+                                                                  choices = c("Benjamini-Hochberg" = "BH",
+                                                                              "Benjamini-Yekutieli" = "BY",
+                                                                              "Bonferroni" = "bonferroni",
+                                                                              "Holm" = "holm",
+                                                                              "Hochberg" = "hochberg",
+                                                                              "Hommel" = "hommel",
+                                                                              "None" = "none"),
+                                                                  selected = "none",
+                                                                  width = "57%"),
                                                       checkboxInput(inputId = 'puri_LR_report',
                                                                     label = 'Item purification',
                                                                     value = FALSE)
@@ -198,20 +235,28 @@ uiReports <-
                                                       withMathJax(),
                                                       radioButtons(inputId = 'type_DDF_report',
                                                                    label = 'Type',
-                                                                   choices = c("\\(H_{0}\\): Any DIF vs. \\(H_{1}\\): No DIF" = 'both',
-                                                                               "\\(H_{0}\\): Uniform DIF vs. \\(H_{1}\\): No DIF" = 'udif',
-                                                                               "\\(H_{0}\\): Non-Uniform DIF vs. \\(H_{1}\\): Uniform DIF" = 'nudif'),
+                                                                   choices = c("\\(H_{0}\\): No DIF vs. \\(H_{1}\\): Any DIF" = 'both',
+                                                                               "\\(H_{0}\\): No DIF vs. \\(H_{1}\\): Uniform DIF" = 'udif',
+                                                                               "\\(H_{0}\\): Uniform DIF vs. \\(H_{1}\\): Non-uniform DIF" = 'nudif'),
                                                                    selected = 'both'),
+                                                      # selectInput(inputId = "matching_DDF_report",
+                                                      #                    label = "DIF matching variable",
+                                                      #                    choices = c("Total score" = "score",
+                                                      #                                "Standardized total score" = "zscore"
+                                                      #                    ),
+                                                      #                    selected = "score",
+                                                      #                    width = "57%"),
                                                       selectInput(inputId = "correction_method_DDF_report",
                                                                   label = "Correction method",
                                                                   choices = c("Benjamini-Hochberg" = "BH",
                                                                               "Benjamini-Yekutieli" = "BY",
+                                                                              "Bonferroni" = "bonferroni",
                                                                               "Holm" = "holm",
                                                                               "Hochberg" = "hochberg",
                                                                               "Hommel" = "hommel",
                                                                               "None" = "none"),
                                                                   selected = "none",
-                                                                  width = "80%"),
+                                                                  width = "57%"),
                                                       checkboxInput(inputId = 'puri_DDF_report',
                                                                     label = 'Item purification',
                                                                     value = FALSE)
@@ -235,7 +280,7 @@ uiReports <-
                                                             label = "Generate report",
                                                             class = "btn btn-primary",
                                                             icon = icon("bar-chart-o"))),
-           tags$style(HTML('#download_report_button { margin-left: 10px }')),
+           tags$style(HTML('#download_report_button { margin-left: 25px }')),
            div(style = "display:inline-block", uiOutput("download_report_button")),
            br(),
            br(),
